.. _windows-platform:

Windows Platform
================

Configuration
-------------

.. literalinclude:: platform.yaml

Overview
--------

The Windows platform configuration is designed to build the application for Windows operating systems using the Clang compiler.

Compile and Link Options
------------------------

- Compile Options: -Wall, -Wextra
- Link Options: -lm

Required Headers
----------------

- windows.h
